==> ViennaCL-1.6.0.tar.gz: ViennaCL-1.6.0/doc/html/annotated.js <==
var annotated =
[
    [ "viennacl", "namespaceviennacl.html", "namespaceviennacl" ],
    [ "dense_matrix", "classdense__matrix.html", "classdense__matrix" ],
    [ "matrix_maker", "structmatrix__maker.html", null ],
    [ "matrix_maker< boost::numeric::ublas::matrix< T >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4" ],
    [ "matrix_maker< boost::numeric::ublas::matrix_range< MatrixT >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4" ],
    [ "matrix_maker< boost::numeric::ublas::matrix_slice< MatrixT >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4" ],
    [ "my_inserter", "classmy__inserter.html", "classmy__inserter" ],
    [ "testData", "structtest_data.html", "structtest_data" ],
    [ "Timer", "class_timer.html", "class_timer" ],
    [ "ViennaCLBackend_impl", "struct_vienna_c_l_backend__impl.html", "struct_vienna_c_l_backend__impl" ],
    [ "ViennaCLCUDABackend_impl", "struct_vienna_c_l_c_u_d_a_backend__impl.html", null ],
    [ "ViennaCLHostBackend_impl", "struct_vienna_c_l_host_backend__impl.html", null ],
    [ "ViennaCLHostScalar_impl", "struct_vienna_c_l_host_scalar__impl.html", "struct_vienna_c_l_host_scalar__impl" ],
    [ "ViennaCLMatrix_impl", "struct_vienna_c_l_matrix__impl.html", "struct_vienna_c_l_matrix__impl" ],
    [ "ViennaCLOpenCLBackend_impl", "struct_vienna_c_l_open_c_l_backend__impl.html", "struct_vienna_c_l_open_c_l_backend__impl" ],
    [ "ViennaCLScalar_impl", "struct_vienna_c_l_scalar__impl.html", "struct_vienna_c_l_scalar__impl" ],
    [ "ViennaCLVector_impl", "struct_vienna_c_l_vector__impl.html", "struct_vienna_c_l_vector__impl" ]
];

==> ViennaCL-1.6.1.tar.gz: ViennaCL-1.6.1/doc/html/annotated.js <==
var annotated =
[
    [ "viennacl", "namespaceviennacl.html", "namespaceviennacl" ],
    [ "dense_matrix", "classdense__matrix.html", "classdense__matrix" ],
    [ "matrix_maker", "structmatrix__maker.html", null ],
    [ "matrix_maker< boost::numeric::ublas::matrix< T >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4.html", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix_3_01_t_01_4_00_01_f_01_4" ],
    [ "matrix_maker< boost::numeric::ublas::matrix_range< MatrixT >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4.html", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__range_3_01_matrix_t_01_4_00_01_f_01_4" ],
    [ "matrix_maker< boost::numeric::ublas::matrix_slice< MatrixT >, F >", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4.html", "structmatrix__maker_3_01boost_1_1numeric_1_1ublas_1_1matrix__slice_3_01_matrix_t_01_4_00_01_f_01_4" ],
    [ "my_inserter", "classmy__inserter.html", "classmy__inserter" ],
    [ "op_assign", "structop__assign.html", null ],
    [ "op_minus_assign", "structop__minus__assign.html", null ],
    [ "op_plus_assign", "structop__plus__assign.html", null ],
    [ "testData", "structtest_data.html", "structtest_data" ],
    [ "Timer", "class_timer.html", "class_timer" ],
    [ "vector_proxy", "classvector__proxy.html", "classvector__proxy" ],
    [ "ViennaCLBackend_impl", "struct_vienna_c_l_backend__impl.html", "struct_vienna_c_l_backend__impl" ],
    [ "ViennaCLCUDABackend_impl", "struct_vienna_c_l_c_u_d_a_backend__impl.html", null ],
    [ "ViennaCLHostBackend_impl", "struct_vienna_c_l_host_backend__impl.html", null ],
    [ "ViennaCLHostScalar_impl", "struct_vienna_c_l_host_scalar__impl.html", "struct_vienna_c_l_host_scalar__impl" ],
    [ "ViennaCLMatrix_impl", "struct_vienna_c_l_matrix__impl.html", "struct_vienna_c_l_matrix__impl" ],
    [ "ViennaCLOpenCLBackend_impl", "struct_vienna_c_l_open_c_l_backend__impl.html", "struct_vienna_c_l_open_c_l_backend__impl" ],
    [ "ViennaCLScalar_impl", "struct_vienna_c_l_scalar__impl.html", "struct_vienna_c_l_scalar__impl" ],
    [ "ViennaCLVector_impl", "struct_vienna_c_l_vector__impl.html", "struct_vienna_c_l_vector__impl" ]
];
